@@ -4,8 +4,8 @@ combine.rwl <- function(x, y = NULL) {
         dim.y2 <- ncol(y)
         if(dim.x2 > 0 && dim.y2 > 0){
             dim2 <- dim.x2 + dim.y2
-            years.x <- row.names(x)
-            years.y <- row.names(y)
+            years.x <- rownames(x)
+            years.y <- rownames(y)
             min.x <- as.numeric(years.x[1])
             min.y <- as.numeric(years.y[1])
             max.x <- as.numeric(years.x[length(years.x)])
@@ -13,13 +13,11 @@ combine.rwl <- function(x, y = NULL) {
             min.year <- min(min.x, min.y)
             years <- min.year:max(max.x, max.y)
             new <- matrix(NA, nrow = length(years), ncol = dim2)
-            new[(min.x-min.year+1):(max.x-min.year+1), seq_len(dim.x2)] <-
-                as.matrix(x)
-            new[(min.y-min.year+1):(max.y-min.year+1), (dim.x2+1):dim2] <-
-                as.matrix(y)
+            new[(min.x-min.year+1):(max.x-min.year+1), seq_len(dim.x2)] <- x
+            new[(min.y-min.year+1):(max.y-min.year+1), (dim.x2+1):dim2] <- y
             rownames(new) <- years
-            colnames(new) <- c(names(x), names(y))
-            as.data.frame(new)
+            colnames(new) <- c(colnames(x), colnames(y))
+            new
         } else if(dim.y2 == 0) {
             x
         } else {
@@ -33,16 +31,16 @@ combine.rwl <- function(x, y = NULL) {
     if (is.list(x)) {
         n <- length(x)
         if (n > 0 && all(sapply(x, is.data.frame))) {
-            new.frame <- x[[1]]
+            new.mat <- as.matrix(x[[1]])
             for (i in inc(2, n))
-                new.frame <- combinator(new.frame, x[[i]])
+                new.mat <- combinator(new.mat, as.matrix(x[[i]]))
         } else if (is.data.frame(x) && is.data.frame(y)) {
-            new.frame <- combinator(x, y)
+            new.mat <- combinator(as.matrix(x), as.matrix(y))
         } else {
             stop("Nothing to combine here. Please supply data.frames formatted according to the data standards in dplR.")
         }
     } else {
         stop("Nothing to combine here. Please supply data.frames formatted according to the data standards in dplR.")
     }
-    new.frame
+    as.data.frame(new.mat)
 }
